@@ -23,9 +23,10 @@
 function quicksave_init()
 {
 
-   if (!@include_once (SM_PATH . 'plugins/quicksave/config.php'))
-      if (!@include_once (SM_PATH . 'plugins/quicksave/config.sample.php'))
-         return FALSE;
+   if (!@include_once (SM_PATH . 'config/config_quicksave.php'))
+      if (!@include_once (SM_PATH . 'plugins/quicksave/config.php'))
+         if (!@include_once (SM_PATH . 'plugins/quicksave/config_default.php'))
+            return FALSE;
 
    return TRUE;
 
