@@ -1059,7 +1059,7 @@ EOS;
          prand += pwd.charCodeAt(i).toString();
       }
       var sPos = Math.floor(prand.length / 5);
-      var mult = parseInt(prand.charAt(sPos) + prand.charAt(sPos*2) + prand.charAt(sPos*3) + prand.charAt(sPos*4) + prand.charAt(sPos*5));
+      var mult = parseInt(prand.charAt(sPos) + prand.charAt(sPos*2) + prand.charAt(sPos*3) + prand.charAt(sPos*4) + prand.charAt(sPos*5), 10);
       var incr = Math.ceil(pwd.length / 2);
       var modu = Math.pow(2, 31) - 1;
       if(mult < 2) {
@@ -1114,7 +1114,7 @@ EOS;
          prand += pwd.charCodeAt(i).toString();
       }
       var sPos = Math.floor(prand.length / 5);
-      var mult = parseInt(prand.charAt(sPos) + prand.charAt(sPos*2) + prand.charAt(sPos*3) + prand.charAt(sPos*4) + prand.charAt(sPos*5));
+      var mult = parseInt(prand.charAt(sPos) + prand.charAt(sPos*2) + prand.charAt(sPos*3) + prand.charAt(sPos*4) + prand.charAt(sPos*5), 10);
       var incr = Math.round(pwd.length / 2);
       var modu = Math.pow(2, 31) - 1;
       var salt = parseInt(str.substring(str.length - 8, str.length), 16);
